Documentation
¶
Overview ¶
Package v1 is the v1 version of the API. +groupName=verrazzano.io
Index ¶
- Variables
- func Kind(kind string) schema.GroupKind
- func Resource(resource string) schema.GroupResource
- type API
- type AlertManager
- type ContainerConfig
- type ContainerSpec
- type Database
- type Elasticsearch
- type ElasticsearchNode
- type Grafana
- type HTTPSpec
- type IndexManagementPolicy
- type Kibana
- type Metric
- type NodeRole
- type OpenSearchDashboardsPlugins
- type OpenSearchPlugins
- type Prometheus
- type Resources
- type RolloverPolicy
- type ScriptConfig
- type ScriptSpec
- type Storage
- type VerrazzanoMonitoringInstance
- func (in *VerrazzanoMonitoringInstance) DeepCopy() *VerrazzanoMonitoringInstance
- func (in *VerrazzanoMonitoringInstance) DeepCopyInto(out *VerrazzanoMonitoringInstance)
- func (in *VerrazzanoMonitoringInstance) DeepCopyObject() runtime.Object
- func (c *VerrazzanoMonitoringInstance) GetObjectKind() schema.ObjectKind
- func (c *VerrazzanoMonitoringInstance) Hash() (uint32, error)
- type VerrazzanoMonitoringInstanceList
- func (in *VerrazzanoMonitoringInstanceList) DeepCopy() *VerrazzanoMonitoringInstanceList
- func (in *VerrazzanoMonitoringInstanceList) DeepCopyInto(out *VerrazzanoMonitoringInstanceList)
- func (in *VerrazzanoMonitoringInstanceList) DeepCopyObject() runtime.Object
- func (c *VerrazzanoMonitoringInstanceList) GetObjectKind() schema.ObjectKind
- type VerrazzanoMonitoringInstanceSpec
- type VerrazzanoMonitoringInstanceStatus
- type Versioning
Constants ¶
This section is empty.
Variables ¶
var ( // SchemeBuilder is used to add go types to the GroupVersionKind scheme SchemeBuilder = runtime.NewSchemeBuilder(addKnownTypes) // AddToScheme to add scheme from SchemaBuilder AddToScheme = SchemeBuilder.AddToScheme )
var SchemeGroupVersion = schema.GroupVersion{Group: vmcontroller.GroupName, Version: "v1"}
SchemeGroupVersion is group version used to register these objects
Functions ¶
func Resource ¶
func Resource(resource string) schema.GroupResource
Resource takes an unqualified resource and returns a Group qualified GroupResource
Types ¶
type API ¶
type API struct {
Replicas int32 `json:"replicas,omitempty"`
}
API details
func (*API) DeepCopy ¶
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new API.
func (*API) DeepCopyInto ¶
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type AlertManager ¶
type AlertManager struct {
Enabled bool `json:"enabled" yaml:"enabled"`
Config string `json:"config,omitempty"`
ConfigMap string `json:"configMap,omitempty"`
VersionsConfigMap string `json:"versionsConfigMap,omitempty"`
Resources Resources `json:"resources,omitempty"`
Replicas int32 `json:"replicas,omitempty"`
}
AlertManager details
func (*AlertManager) DeepCopy ¶
func (in *AlertManager) DeepCopy() *AlertManager
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new AlertManager.
func (*AlertManager) DeepCopyInto ¶
func (in *AlertManager) DeepCopyInto(out *AlertManager)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type ContainerConfig ¶
type ContainerConfig struct {
Image string
Args []string
EnvFrom []corev1.EnvFromSource
Env []corev1.EnvVar
}
ContainerConfig describes config needed run a container
func (*ContainerConfig) DeepCopy ¶
func (in *ContainerConfig) DeepCopy() *ContainerConfig
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ContainerConfig.
func (*ContainerConfig) DeepCopyInto ¶
func (in *ContainerConfig) DeepCopyInto(out *ContainerConfig)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type ContainerSpec ¶
type ContainerSpec struct {
Image string `json:"image,omitempty"`
ImagePullSecrets []corev1.LocalObjectReference `json:"imagePullSecrets,omitempty"`
Args []string `json:"args,omitempty"`
EnvFrom []corev1.EnvFromSource `json:"envFrom,omitempty" protobuf:"bytes,19,rep,name=envFrom"`
Env []corev1.EnvVar `json:"env,omitempty" patchStrategy:"merge" patchMergeKey:"name" protobuf:"bytes,7,rep,name=env"`
Volumes []corev1.Volume `json:"volumes,omitempty" patchStrategy:"merge" patchMergeKey:"name" protobuf:"bytes,1,rep,name=volumes"`
VolumeMounts []corev1.VolumeMount `json:"volumeMounts,omitempty" patchStrategy:"merge" patchMergeKey:"mountPath" protobuf:"bytes,9,rep,name=volumeMounts"`
}
ContainerSpec represents a container image that needs to be run periodically
func (*ContainerSpec) DeepCopy ¶
func (in *ContainerSpec) DeepCopy() *ContainerSpec
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ContainerSpec.
func (*ContainerSpec) DeepCopyInto ¶
func (in *ContainerSpec) DeepCopyInto(out *ContainerSpec)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type Database ¶ added in v0.0.29
type Database struct {
PasswordSecret string `json:"passwordSecret,omitempty"`
Host string `json:"host,omitempty"`
Name string `json:"name,omitempty"`
}
Database details
func (*Database) DeepCopy ¶ added in v0.0.29
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new Database.
func (*Database) DeepCopyInto ¶ added in v0.0.29
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type Elasticsearch ¶
type Elasticsearch struct {
Enabled bool `json:"enabled" yaml:"enabled"`
Storage Storage `json:"storage,omitempty"`
IngestNode ElasticsearchNode `json:"ingestNode,omitempty"`
MasterNode ElasticsearchNode `json:"masterNode,omitempty"`
DataNode ElasticsearchNode `json:"dataNode,omitempty"`
Policies []IndexManagementPolicy `json:"policies,omitempty"`
Nodes []ElasticsearchNode `json:"nodes,omitempty"`
Plugins OpenSearchPlugins `json:"plugins,omitempty"`
}
Elasticsearch details
func (*Elasticsearch) DeepCopy ¶
func (in *Elasticsearch) DeepCopy() *Elasticsearch
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new Elasticsearch.
func (*Elasticsearch) DeepCopyInto ¶
func (in *Elasticsearch) DeepCopyInto(out *Elasticsearch)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type ElasticsearchNode ¶
type ElasticsearchNode struct {
Name string `json:"name,omitempty"`
Replicas int32 `json:"replicas,omitempty"`
JavaOpts string `json:"javaOpts" yaml:"javaOpts,omitempty"`
Resources Resources `json:"resources,omitempty"`
Storage *Storage `json:"storage,omitempty"`
Roles []NodeRole `json:"roles,omitempty"`
}
ElasticsearchNode Type details
func (*ElasticsearchNode) DeepCopy ¶
func (in *ElasticsearchNode) DeepCopy() *ElasticsearchNode
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ElasticsearchNode.
func (*ElasticsearchNode) DeepCopyInto ¶
func (in *ElasticsearchNode) DeepCopyInto(out *ElasticsearchNode)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type Grafana ¶
type Grafana struct {
Enabled bool `json:"enabled" yaml:"enabled"`
Storage Storage `json:"storage,omitempty"`
DatasourcesConfigMap string `json:"datasourcesConfigMap,omitempty"`
DashboardsConfigMap string `json:"dashboardsConfigMap,omitempty"`
Resources Resources `json:"resources,omitempty"`
Replicas int32 `json:"replicas,omitempty"`
Database *Database `json:"database,omitempty"`
}
Grafana details
func (*Grafana) DeepCopy ¶
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new Grafana.
func (*Grafana) DeepCopyInto ¶
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type HTTPSpec ¶
HTTPSpec represetns a script that needs to be run periodically
func (*HTTPSpec) DeepCopy ¶
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new HTTPSpec.
func (*HTTPSpec) DeepCopyInto ¶
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type IndexManagementPolicy ¶ added in v0.0.29
type IndexManagementPolicy struct {
// Name of the policy
PolicyName string `json:"policyName"`
// Index pattern the policy will be matched to
IndexPattern string `json:"indexPattern"`
// Minimum age of an index before it is automatically deleted
// +kubebuilder:validation:Pattern:=^[0-9]+(d|h|m|s|ms|micros|nanos)$
MinIndexAge *string `json:"minIndexAge,omitempty"`
Rollover RolloverPolicy `json:"rollover,omitempty"`
}
IndexManagementPolicy Defines a policy for managing indices
func (*IndexManagementPolicy) DeepCopy ¶ added in v0.0.29
func (in *IndexManagementPolicy) DeepCopy() *IndexManagementPolicy
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new IndexManagementPolicy.
func (*IndexManagementPolicy) DeepCopyInto ¶ added in v0.0.29
func (in *IndexManagementPolicy) DeepCopyInto(out *IndexManagementPolicy)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type Kibana ¶
type Kibana struct {
Enabled bool `json:"enabled" yaml:"enabled"`
Resources Resources `json:"resources,omitempty"`
Replicas int32 `json:"replicas,omitempty"`
Plugins OpenSearchDashboardsPlugins `json:"plugins,omitempty"`
}
Kibana details
func (*Kibana) DeepCopy ¶
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new Kibana.
func (*Kibana) DeepCopyInto ¶
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type Metric ¶
type Metric struct {
Name string `json:"name" yaml:"name"`
// Metric Type. One of Gauge | Counter | Summary | Histogram
Type string `json:"type" yaml:"type"`
// Help Text message
Help string `json:"help" yaml:"help"`
// Labels is an Acceptable list that can be attached to a metric
Labels []string `json:"labels" yaml:"labels"`
//Percentiles to be used for Summary type metric
Percentiles []float64 `json:"percentiles,omitempty" yaml:"percentiles"`
//Buckets to be used for Histogram type metric
Buckets []float64 `json:"buckets,omitempty" yaml:"buckets"`
}
Metric that represents
func (*Metric) DeepCopy ¶
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new Metric.
func (*Metric) DeepCopyInto ¶
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type OpenSearchDashboardsPlugins ¶ added in v0.0.30
type OpenSearchDashboardsPlugins OpenSearchPlugins
OpenSearchDashboardsPlugins is an alias of OpenSearchPlugins as both have the same properties. Enable to add 3rd Party / Custom plugins not offered in the default OpenSearch-Dashboards image
func (*OpenSearchDashboardsPlugins) DeepCopy ¶ added in v0.0.30
func (in *OpenSearchDashboardsPlugins) DeepCopy() *OpenSearchDashboardsPlugins
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new OpenSearchDashboardsPlugins.
func (*OpenSearchDashboardsPlugins) DeepCopyInto ¶ added in v0.0.30
func (in *OpenSearchDashboardsPlugins) DeepCopyInto(out *OpenSearchDashboardsPlugins)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type OpenSearchPlugins ¶ added in v0.0.30
type OpenSearchPlugins struct {
// To enable or disable the non-bundled plugins installation.
Enabled bool `json:"enabled" yaml:"enabled"`
// InstallList could be the list of plugin names, URLs to the plugin zip file or Maven coordinates.
InstallList []string `json:"installList,omitempty"`
}
OpenSearchPlugins Enable to add 3rd Party / Custom plugins not offered in the default OpenSearch image
func (*OpenSearchPlugins) DeepCopy ¶ added in v0.0.30
func (in *OpenSearchPlugins) DeepCopy() *OpenSearchPlugins
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new OpenSearchPlugins.
func (*OpenSearchPlugins) DeepCopyInto ¶ added in v0.0.30
func (in *OpenSearchPlugins) DeepCopyInto(out *OpenSearchPlugins)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type Prometheus ¶
type Prometheus struct {
Enabled bool `json:"enabled" yaml:"enabled"`
Storage Storage `json:"storage,omitempty"`
ConfigMap string `json:"configMap,omitempty"`
VersionsConfigMap string `json:"versionsConfigMap,omitempty"`
RulesConfigMap string `json:"rulesConfigMap,omitempty"`
RulesVersionsConfigMap string `json:"rulesVersionsConfigMap,omitempty"`
Resources Resources `json:"resources,omitempty"`
RetentionPeriod int32 `json:"retentionPeriod,omitempty"`
Replicas int32 `json:"replicas,omitempty"`
HTTP2Enabled bool `json:"http2Enabled,omitempty" yaml:"http2Enabled"`
}
Prometheus details
func (*Prometheus) DeepCopy ¶
func (in *Prometheus) DeepCopy() *Prometheus
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new Prometheus.
func (*Prometheus) DeepCopyInto ¶
func (in *Prometheus) DeepCopyInto(out *Prometheus)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type Resources ¶
type Resources struct {
// +kubebuilder:validation:Pattern:=^([+-]?[0-9.]+)([eEinumkKMGTP]*[-+]?[0-9]*)$
LimitCPU string `json:"limitCPU,omitempty"`
// +kubebuilder:validation:Pattern:=^([+-]?[0-9.]+)([eEinumkKMGTP]*[-+]?[0-9]*)$
LimitMemory string `json:"limitMemory,omitempty"`
// +kubebuilder:validation:Pattern:=^([+-]?[0-9.]+)([eEinumkKMGTP]*[-+]?[0-9]*)$
RequestCPU string `json:"requestCPU,omitempty"`
// +kubebuilder:validation:Pattern:=^([+-]?[0-9.]+)([eEinumkKMGTP]*[-+]?[0-9]*)$
RequestMemory string `json:"requestMemory,omitempty"`
// These fields are not used anywhere
// +kubebuilder:validation:Pattern:=^([+-]?[0-9.]+)([eEinumkKMGTP]*[-+]?[0-9]*)$
MaxSizeDisk string `json:"maxSizeDisk,omitempty" yaml:"maxSizeDisk,omitempty"`
// +kubebuilder:validation:Pattern:=^([+-]?[0-9.]+)([eEinumkKMGTP]*[-+]?[0-9]*)$
MinSizeDisk string `json:"minSizeDisk,omitempty" yaml:"minSizeDisk,omitempty"`
}
Resources details
func (*Resources) DeepCopy ¶
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new Resources.
func (*Resources) DeepCopyInto ¶
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type RolloverPolicy ¶ added in v0.0.29
type RolloverPolicy struct {
// Minimum age of an index before it is rolled over
// +kubebuilder:validation:Pattern:=^[0-9]+(d|h|m|s|ms|micros|nanos)$
MinIndexAge *string `json:"minIndexAge,omitempty"`
// Minimum size of an index before it is rolled over
// e.g., 20mb, 5gb, etc.
// +kubebuilder:validation:Pattern:=^[0-9]+(b|kb|mb|gb|tb|pb)$
MinSize *string `json:"minSize,omitempty"`
// Minimum count of documents in an index before it is rolled over
MinDocCount *int `json:"minDocCount,omitempty"`
}
RolloverPolicy Settings for Index Management rollover
func (*RolloverPolicy) DeepCopy ¶ added in v0.0.29
func (in *RolloverPolicy) DeepCopy() *RolloverPolicy
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new RolloverPolicy.
func (*RolloverPolicy) DeepCopyInto ¶ added in v0.0.29
func (in *RolloverPolicy) DeepCopyInto(out *RolloverPolicy)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type ScriptConfig ¶
type ScriptConfig struct {
File string
}
ScriptConfig describes the config needed to run the script
func (*ScriptConfig) DeepCopy ¶
func (in *ScriptConfig) DeepCopy() *ScriptConfig
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ScriptConfig.
func (*ScriptConfig) DeepCopyInto ¶
func (in *ScriptConfig) DeepCopyInto(out *ScriptConfig)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type ScriptSpec ¶
type ScriptSpec struct {
Content string `json:"content,omitempty"`
}
ScriptSpec represents a script that needs to be run periodically
func (*ScriptSpec) DeepCopy ¶
func (in *ScriptSpec) DeepCopy() *ScriptSpec
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ScriptSpec.
func (*ScriptSpec) DeepCopyInto ¶
func (in *ScriptSpec) DeepCopyInto(out *ScriptSpec)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type Storage ¶
type Storage struct {
Size string `json:"size,omitempty" yaml:"size"`
AvailabilityDomain string `json:"availabilityDomain,omitempty" yaml:"availabilityDomain"`
PvcNames []string `json:"pvcNames,omitempty" yaml:"pvcNames,omitempty"`
}
Storage details
func (*Storage) DeepCopy ¶
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new Storage.
func (*Storage) DeepCopyInto ¶
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type VerrazzanoMonitoringInstance ¶
type VerrazzanoMonitoringInstance struct {
metav1.TypeMeta `json:",inline"`
metav1.ObjectMeta `json:"metadata"`
Spec VerrazzanoMonitoringInstanceSpec `json:"spec"`
Status VerrazzanoMonitoringInstanceStatus `json:"status"`
}
VerrazzanoMonitoringInstance Represents a CRD +genclient +genclient:noStatus +k8s:deepcopy-gen:interfaces=k8s.io/apimachinery/pkg/runtime.Object +kubebuilder:resource:shortName=vmi
func (*VerrazzanoMonitoringInstance) DeepCopy ¶
func (in *VerrazzanoMonitoringInstance) DeepCopy() *VerrazzanoMonitoringInstance
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new VerrazzanoMonitoringInstance.
func (*VerrazzanoMonitoringInstance) DeepCopyInto ¶
func (in *VerrazzanoMonitoringInstance) DeepCopyInto(out *VerrazzanoMonitoringInstance)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*VerrazzanoMonitoringInstance) DeepCopyObject ¶
func (in *VerrazzanoMonitoringInstance) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
func (*VerrazzanoMonitoringInstance) GetObjectKind ¶
func (c *VerrazzanoMonitoringInstance) GetObjectKind() schema.ObjectKind
GetObjectKind to get kind
func (*VerrazzanoMonitoringInstance) Hash ¶
func (c *VerrazzanoMonitoringInstance) Hash() (uint32, error)
Hash function to identify VerrazzanoMonitoringInstance changes
type VerrazzanoMonitoringInstanceList ¶
type VerrazzanoMonitoringInstanceList struct {
metav1.TypeMeta `json:",inline"`
metav1.ListMeta `json:"metadata"`
Items []VerrazzanoMonitoringInstance `json:"items"`
}
VerrazzanoMonitoringInstanceList Represents a collection of CRDs +k8s:deepcopy-gen:interfaces=k8s.io/apimachinery/pkg/runtime.Object
func (*VerrazzanoMonitoringInstanceList) DeepCopy ¶
func (in *VerrazzanoMonitoringInstanceList) DeepCopy() *VerrazzanoMonitoringInstanceList
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new VerrazzanoMonitoringInstanceList.
func (*VerrazzanoMonitoringInstanceList) DeepCopyInto ¶
func (in *VerrazzanoMonitoringInstanceList) DeepCopyInto(out *VerrazzanoMonitoringInstanceList)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*VerrazzanoMonitoringInstanceList) DeepCopyObject ¶
func (in *VerrazzanoMonitoringInstanceList) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
func (*VerrazzanoMonitoringInstanceList) GetObjectKind ¶
func (c *VerrazzanoMonitoringInstanceList) GetObjectKind() schema.ObjectKind
GetObjectKind to get kind
type VerrazzanoMonitoringInstanceSpec ¶
type VerrazzanoMonitoringInstanceSpec struct {
// Version details
Versioning Versioning `json:"versioning,omitempty" yaml:"versioning"`
// If lock, controller will not sync/process the VerrazzanoMonitoringInstance env
Lock bool `json:"lock" yaml:"lock"`
// the external endpoint or uniform resource identifier
URI string `json:"uri,omitempty" yaml:"uri"`
// the ingress class for external endpoints
IngressClassName *string `json:"IngressClassName,omitempty"`
// a secret which contains secrets VerrazzanoMonitoringInstance needs to startup
// examples being username, password, tls.crt, tls.key
SecretsName string `json:"secretsName" yaml:"secretsName"`
// the nginx ingress controller tls cert secret
SecretName string `json:"-" yaml:"-"`
// auto generate a SSL certificate
AutoSecret bool `json:"autoSecret" yaml:"autoSecret"`
// Will use this as the target in ingress annotations, use this when using OCI LB and
// external-dns so that we point to the svc CNAME created
IngressTargetDNSName string `json:"ingressTargetDNSName" yaml:"ingressTargetDNSName"`
// CascadingDelete for cascade deletion of related objects when the VerrazzanoMonitoringInstance is deleted
CascadingDelete bool `json:"cascadingDelete" yaml:"cascadingDelete"`
// Grafana details
Grafana Grafana `json:"grafana"`
// Prometheus details
Prometheus Prometheus `json:"prometheus"`
// Prometheus details
AlertManager AlertManager `json:"alertmanager"`
// Elasticsearch details
Elasticsearch Elasticsearch `json:"elasticsearch"`
// Kibana details
Kibana Kibana `json:"kibana"`
// API details
API API `json:"api,omitempty"`
// Service type for component services
ServiceType corev1.ServiceType `json:"serviceType" yaml:"serviceType"`
ContactEmail string `json:"contactemail,omitempty" yaml:"contactemail,omitempty"`
NatGatewayIPs []string `json:"natGatewayIPs,omitempty" yaml:"natGatewayIPs,omitempty"`
// +optional
StorageClass *string `json:"storageClass,omitempty"`
}
VerrazzanoMonitoringInstanceSpec defines the attributes a user can specify when creating a VerrazzanoMonitoringInstance
func (*VerrazzanoMonitoringInstanceSpec) DeepCopy ¶
func (in *VerrazzanoMonitoringInstanceSpec) DeepCopy() *VerrazzanoMonitoringInstanceSpec
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new VerrazzanoMonitoringInstanceSpec.
func (*VerrazzanoMonitoringInstanceSpec) DeepCopyInto ¶
func (in *VerrazzanoMonitoringInstanceSpec) DeepCopyInto(out *VerrazzanoMonitoringInstanceSpec)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type VerrazzanoMonitoringInstanceStatus ¶
type VerrazzanoMonitoringInstanceStatus struct {
// The name of the operator environment in which this VerrazzanoMonitoringInstance instance lives
EnvName string `json:"envName" yaml:"envName"`
State string `json:"state" yaml:"state"`
CreationTime *metav1.Time `json:"creationTime,omitempty" yaml:"creationTime"`
Hash uint32 `json:"hash"`
}
VerrazzanoMonitoringInstanceStatus Object tracks the current running VerrazzanoMonitoringInstance state
func (*VerrazzanoMonitoringInstanceStatus) DeepCopy ¶
func (in *VerrazzanoMonitoringInstanceStatus) DeepCopy() *VerrazzanoMonitoringInstanceStatus
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new VerrazzanoMonitoringInstanceStatus.
func (*VerrazzanoMonitoringInstanceStatus) DeepCopyInto ¶
func (in *VerrazzanoMonitoringInstanceStatus) DeepCopyInto(out *VerrazzanoMonitoringInstanceStatus)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type Versioning ¶
type Versioning struct {
CurrentVersion string `json:"currentVersion,omitempty" yaml:"currentVersion"`
DesiredVersion string `json:"desiredVersion,omitempty" yaml:"desiredVersion"`
}
Versioning details
func (*Versioning) DeepCopy ¶
func (in *Versioning) DeepCopy() *Versioning
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new Versioning.
func (*Versioning) DeepCopyInto ¶
func (in *Versioning) DeepCopyInto(out *Versioning)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.